@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "swiper" "0.15.1"
+(define-package "swiper" "20260101.2125"
   "Isearch with an overview.  Oh, man!."
   '((emacs "24.5")
     (ivy   "0.15.1"))
   :url "https://github.com/abo-abo/swiper"
-  :commit "e33b028ed4b1258a211c87fd5fe801bed25de429"
-  :revdesc "0.15.1-0-ge33b028ed4b1"
+  :commit "d489b4f0d48fd215119261d92de103c5b5580895"
+  :revdesc "d489b4f0d48f"
   :keywords '("matching")
   :authors '(("Oleh Krehel" . "ohwoeowho@gmail.com"))
   :maintainers '(("Basil L. Contovounesios" . "basil@contovou.net")))
